﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using DataAccess;
using RadControlsWinFormsApp.Properties;
using Telerik.WinControls;
using Telerik.WinControls.UI;
using Telerik.WinControls.UI.Export;

namespace RadControlsWinFormsApp.Q12011.Updated
{
    public partial class C_RadGridViewDemo : Telerik.WinControls.UI.RadForm
    {
        DataTable folders = new DataTable("folders");
        DataTable files = new DataTable("files");
        Image folder = Resources.folder_open;
        Image file = Resources.document;

        public C_RadGridViewDemo()
        {
            InitializeComponent();
            FillGrid1();
            FillGrid2();
        }

        private void FillGrid2()
        {
            StoreModelContext context = new StoreModelContext();
            radGridView2.DataSource = context.Categories.ToList();
            radGridView2.AutoGenerateHierarchy = true;
        }

        public void FillGrid1()
        {
            this.radGridView1.CellFormatting += 
                new CellFormattingEventHandler(radGridView1_CellFormatting);

            InitializeFolders();
            InitializeFiles();

            this.radGridView1.AutoSizeColumnsMode = 
                Telerik.WinControls.UI.GridViewAutoSizeColumnsMode.Fill;

            DataSet dataSet = new DataSet();
            dataSet.Tables.Add(folders);
            dataSet.Tables.Add(files);

            dataSet.Relations.Add(new DataRelation("FoldersSelfRef", folders.Columns["ID"], folders.Columns["ParentID"]));
            dataSet.Relations.Add(new DataRelation("FoldersFiles", folders.Columns["ID"], files.Columns["FolderID"]));

            this.radGridView1.DataSource = dataSet;
            this.radGridView1.DataMember = "folders";
            this.radGridView1.AutoGenerateHierarchy = true;

            this.radGridView1.Columns["ID"].IsVisible = false;
            this.radGridView1.Columns["ParentID"].IsVisible = false;
            this.radGridView1.Columns["Size"].MaxWidth = 100;

            GridViewTemplate template = this.radGridView1.MasterTemplate.Templates[0];
            template.AutoSizeColumnsMode = GridViewAutoSizeColumnsMode.Fill;
            template.Columns["ID"].IsVisible = false;
            template.Columns["FolderID"].IsVisible = false;
        }

        void radGridView1_CellFormatting(object sender, CellFormattingEventArgs e)
        {
            e.CellElement.TextImageRelation = TextImageRelation.ImageBeforeText;
            e.CellElement.ImageAlignment = ContentAlignment.MiddleLeft;
            e.CellElement.TextAlignment = ContentAlignment.MiddleLeft;
            if (e.CellElement.ViewTemplate.Parent == null)
            {
                if (e.CellElement.ColumnInfo.Name == "Name")
                {
                    e.CellElement.Image = folder;
                }
                else
                {
                    e.CellElement.Image = null;
                }
            }
            else
            {
                if (e.CellElement.ColumnInfo.Name == "Name")
                {
                    e.CellElement.Image = file;
                }
                else
                {
                    e.CellElement.Image = null;
                }
            }
        }

        private void InitializeFiles()
        {
            files.Columns.Add("ID", typeof(int));
            files.Columns.Add("FolderID", typeof(int));
            files.Columns.Add("Name", typeof(string));
            files.Columns.Add("Size", typeof(int));
            files.Columns.Add("DateModified", typeof(DateTime));

            DataRow fileRecord = files.NewRow();
            fileRecord[0] = 0;
            fileRecord[1] = 9;
            fileRecord[2] = "ToDo.txt";
            fileRecord[3] = 12;
            fileRecord[4] = new DateTime(2010, 05, 12);
            files.Rows.Add(fileRecord);

            fileRecord = files.NewRow();
            fileRecord[0] = 1;
            fileRecord[1] = 9;
            fileRecord[2] = "Salaries.xlsx";
            fileRecord[3] = 77;
            fileRecord[4] = new DateTime(2011, 05, 13);
            files.Rows.Add(fileRecord);

            fileRecord = files.NewRow();
            fileRecord[0] = 2;
            fileRecord[1] = 9;
            fileRecord[2] = "My Analysis.docx";
            fileRecord[3] = 33;
            fileRecord[4] = new DateTime(2010, 06, 1);
            files.Rows.Add(fileRecord);

            fileRecord = files.NewRow();
            fileRecord[0] = 3;
            fileRecord[1] = 2;
            fileRecord[2] = "Thumbs.ini";
            fileRecord[3] = 23;
            fileRecord[4] = new DateTime(2006, 1, 1);
            files.Rows.Add(fileRecord);
        }

        private void InitializeFolders()
        {
            folders.Columns.Add("ID", typeof(int));
            folders.Columns.Add("ParentID", typeof(int));
            folders.Columns.Add("Name", typeof(string));
            folders.Columns.Add("Size", typeof(int));

            DataRow folderRecord = folders.NewRow();
            folderRecord[0] = 0;
            folderRecord[1] = DBNull.Value;
            folderRecord[2] = @"C:\";
            folderRecord[3] = 12345;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 1;
            folderRecord[1] = 0;
            folderRecord[2] = @"Program Files";
            folderRecord[3] = 2345;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 2;
            folderRecord[1] = 0;
            folderRecord[2] = @"Program Files (x86)";
            folderRecord[3] = 5767;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 3;
            folderRecord[1] = 0;
            folderRecord[2] = @"Program Data";
            folderRecord[3] = 2313;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 4;
            folderRecord[1] = 0;
            folderRecord[2] = @"Users";
            folderRecord[3] = 1233;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 5;
            folderRecord[1] = 4;
            folderRecord[2] = @"Administrator";
            folderRecord[3] = 645;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 6;
            folderRecord[1] = 4;
            folderRecord[2] = @"Public";
            folderRecord[3] = 3232;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 7;
            folderRecord[1] = 4;
            folderRecord[2] = @"Test User";
            folderRecord[3] = 1231;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 8;
            folderRecord[1] = 7;
            folderRecord[2] = @"Desktop";
            folderRecord[3] = 7566;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 9;
            folderRecord[1] = 7;
            folderRecord[2] = @"My Documents";
            folderRecord[3] = 653;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 10;
            folderRecord[1] = 7;
            folderRecord[2] = @"My Pictures";
            folderRecord[3] = 234;
            folders.Rows.Add(folderRecord);

            folderRecord = folders.NewRow();
            folderRecord[0] = 11;
            folderRecord[1] = 0;
            folderRecord[2] = @"WINDOWS";
            folderRecord[3] = 654;
            folders.Rows.Add(folderRecord);
        }
    }
}